.\" -*- nroff -*- generated from .Rd format
.BG
.FN DeletionDiagnostics
.FN rstudent
.FN hatvalues
.FN cookd
.FN dfbeta
.FN dfbetas
.FN influence

.TL
Deletion Diagnostics for Linear and Generalized Linear Models
.DN
These functions calculate a variety of leave-one-out deletion diagnostics for
linear and generalized linear models, including studentized residuals (for
outlier detection), hatvalues (for detecting high-leverage observations), and
Cook's distances, dfbeta, and dfbetas (for detecting influential observations).
.IP
Basic quantities are computed by `influence.lm' or `influence.glm'. Values for generalized linear
models are approximations, as described in Williams (1987) (except that Cook's distances are
scaled as F rather than as chi-square values).
.IP  
Normally, the generic versions of these functions are the ones to be used directly. For 
`hatvalues', `dfbeta', and `dfbetas', the method for linear models
also works for generalized linear models. 
.IP  
The following diagnostics are provided:
`rstudent', studentized residuals;
`hatvalues', observation leverages;
`cookd', Cook's distance influence measure for observations;
`dfbeta', change in each coefficient upon deleting observations;
`dfbetas', standardized change in each coefficient for deleting observations.    
    
.CS
rstudent(model, ...)

rstudent.lm(model, infl=influence(model), names=infl$names)

rstudent.glm(model, infl=influence(model), names=infl$names)

hatvalues(model, ...)

hatvalues.lm(model, infl=influence(model), names=infl$names)

cookd(model, ...)

cookd.lm(model, infl=influence(model), sumry=summary(model), names=infl$names)

cookd.glm(model, infl=influence(model), sumry=summary(model), names=infl$names)

dfbeta(model, ...)

dfbeta.lm(model, infl=influence(model), names=infl$names)

dfbetas(model, ...)

dfbetas.lm(model, infl=influence(model), sumry=summary(model), names=infl$names)

influence(model, ...)

influence.lm(model)

influence.glm(model)
.RA
.AG model
`lm' or `glm' model object.
.OA
.AG infl
optionally, an influence-object precomputed for the `model' by `influence'.
.AG sumry
optionally, a summary-object precomputed for the `model' by `summary'.
.AG names
optionally, a vector of observation names.
.AG ...
arguments to be passed down from generic functions to method functions.
.RT
`rstudent', `hatvalues', and `cookd' return vectors with one entry for
each observation; `dfbeta' and `dfbetas' return matrices with rows for 
observations and columns for coefficients.
.IP "" 
`influence' returns a list with entries:
.IP "" 
.AG names
observation names.
.AG hat
hat-values.
.AG sigma
leave-one-out estimates of linear-model standard error or 
generalized-linear-model scale.
.AG coefficients
dfbeta values.
.AG wt.res
weighted residuals (for a linear model).
.AG dev.res
deviance residuals (for a generalized linear model).
.AG pear.res
Pearson residuals (for a generalized linear model).
.SH REFERENCES
Belsley, D. A. and Kuh, E. and Welsch, R. E. (1980)
Regression Diagnostics. Wiley.
.IP 
Cook, R. D. and Weisberg, S. (1984)
Residuals and Influence in Regression. Wiley.
.IP  
Fox, J. (1997)
Applied Regression, Linear Models, and Related Methods. Sage.
.IP 
Williams, D. A. (1987)
Generalized linear model diagnostics using the deviance and single
case deletions. Applied Statistics 36, 181-191.
.EX
attach(Duncan)
mod <- lm(prestige ~ income + education)
qq.plot(rstudent(mod), distribution="t", df=41)
plot(hatvalues(mod))
plot(cookd(mod))
plot(dfbeta(mod)[,2])
plot(dfbetas(mod)[,2])
.KW regression
.KW models
.WR
