.\" -*- nroff -*- generated from .Rd format
.BG
.FN box.cox.var
.TL
Constructed Variable for Box-Cox Transformation
.DN
Computes a constructed variable for the Box-Cox transformation of the
response variable in a linear model.
.IP
The constructed variable is defined as y[log(y/y') -1], where 
y' is the geometric mean of y. 
.IP  
The constructed variable is meant to be
added to the right-hand-side of the linear model. The t-test for the
coefficient of the constructed variable is an approximate score test for whether a
transformation is required. 
.IP  
If b is the coefficient of the constructed variable,
then an estimate of the normalizing power transformation based on the score statistic
is 1 - b. An added-variable plot for the constructed
variable shows leverage and influence on the decision to transform y. 

.CS
box.cox.var(y)
.RA
.AG y
response variable.
.RT
a numeric vector of the same length as `y'.
.SH REFERENCES
Atkinson, A. C. (1985)
Plots, Transformations, and Regression. Oxford.
.IP  
Box, G. E. P. and Cox, D. R. (1964)
An analysis of transformations.
JRSS B 26 211-246.
.IP  
Fox, J. (1997)
Applied Regression, Linear Models, and Related Methods. Sage.
.SA
`box.cox', `box.cox.powers', 
`TransformationAxes', `av.plots'
.EX
mod<-lm(interlocks+1~assets, data=Ornstein)
mod.aux<-update(mod, .~.+box.cox.var(interlocks+1))
summary(mod.aux)
## Call: lm(formula = interlocks + 1 ~ assets + box.cox.var(interlocks + 1), data = 
##     Ornstein)
## . . .
## 
## Coefficients:
##                               Value Std. Error t value Pr(>|t|) 
##                 (Intercept)  14.607   0.543     26.920   0.000 
##                      assets   0.000   0.000     -1.395   0.164 
## box.cox.var(interlocks + 1)   0.743   0.041     17.956   0.000 
## . . .
 
av.plots(mod.aux, "box.cox.var(interlocks + 1)")
.KW regression
.WR
