.\" -*- nroff -*- generated from .Rd format
.BG
.FN leverage.plots
.FN leverage.plot
.TL
Regression Leverage Plots
.DN
These functions display a generalization, due to Sall (1990), 
of added-variable plots to multiple-df terms in a linear model. 
When a term has just 1 df, the leverage plot is a rescaled version
of the usual added-variable (partial-regression) plot.
.IP
The function intended for direct use is `leverage.plots'. By default, this
function is used interactively through a text menu.
.IP  
The model can contain factors and interactions. A leverage plot can be
drawn for each term in the model, including the constant.
.IP  
`leverage.plot.glm' is a dummy function, which generates an error message.
.CS
leverage.plots(model, term.name, ask=missing(term.name), ...)

leverage.plot(model, ...)

leverage.plot.lm(model, term.name, 
  labels=names(residuals(model)[!is.na(residuals(model))]),  
  identify.points=T, las=par('las'), col=2, pch=1, lwd=2, 
  main="Leverage Plot")

leverage.plot.glm(model, ...)
.RA
.AG model
model object produced by `lm'
.AG term.name
name of term in the model to be plotted; this argument is usually
omitted for `leverage.plots'.
.OA
.AG ask
if `TRUE', a menu is provided in the Commands window for the
user to select the term(s) to plot.
.AG labels
observation names.
.AG identify.points
if `TRUE', then identify points interactively.
.AG las
if `0', ticks labels are drawn parallel to the
axis; set to `1' for horizontal labels (see `par').
.AG col
color for points and lines; the default is `2'.
.AG pch
plotting character for points; default is `1' 
(a circle, see `par').
.AG lwd
line width; default is `2' (see `par').
.AG main
title for plot.
.AG ...
not for the user.
.RT
`NULL'. These functions are used for their side effect: producing
plots.
.SH REFERENCES
Fox, J. (1997)
Applied Regression, Linear Models, and Related Methods. Sage.
.IP  
Sall, J. (1990)
Leverage plots for general linear hypotheses.
American Statistician 44, 308-315.
.SA
`av.plots'
.EX  
leverage.plots(lm(prestige~(income+education)*type, data=Duncan))  
.KW hplot
.KW regression
.WR
