.\" -*- nroff -*- generated from .Rd format
.BG
.FN linear.hypothesis
.FN lht
.TL
Test Linear Hypothesis
.DN
Test a linear hypothesis for a linear or generalized linear model.
.IP
Computes an F-test for the hypothesis in a linear model, or a Wald test in a
generalized linear model.
.CS
linear.hypothesis(model, ...)

lht(...)

linear.hypothesis.lm(model, hypothesis.matrix, rhs=0, 
  summary.model=summary(model, corr = FALSE), 
  white.adjust=F, error.SS, error.df)

linear.hypothesis.glm(model, hypothesis.matrix, rhs=0, 
  summary.model=summary(model, corr = FALSE))
  
print.chisq.test(x, ...)

print.F.test(x, ...)
.RA
.AG model
model object produced by `lm' or `glm'.
.AG hypothesis.matrix
matrix (or vector) giving linear combinations
of coefficients by rows.
.OA
.AG rhs
right-hand-side vector for hypothesis, with as many entries as
rows in `hypothesis.matrix'.
.AG summary.model
a `summary' object for the model; usually specified
only when `linear.hypothesis' is called from another function that has
already computed the summary.
.AG white.adjust
if `TRUE' use heteroscedasticity-corrected covariance matrix.
.AG error.SS
error sum of squares for the hypothesis; if not specified, will be
taken from `model'.
.AG error.df
error degrees of freedom for the hypothesis; if not specified,
will be taken from `model'.
.AG x
`chisq.test' or `F.test' object.
.AG ...
aruments to pass down.
.RT
Returns an `F.test' or `chisq.test' object, with components:
.AG SSH
sum of squares for hypothesis (for a linear model).
.AG SSE
error sum of squares (for a linear model).
.AG F
F-statistic for the hypothesis (for a linear model.)
.AG Df
degrees of freedom for F or chisquare.
.AG p
p-value for the hypothesis.
.AG ChiSquare
chisquare statistic for the hypothesis (for a generalized linear model).
.SH REFERENCES
Fox, J. (1997)
Applied Regression, Linear Models, and Related Methods. Sage.
.SA
`anova', `Anova', `hccm'
.EX
mod<-lm(weight~repwt, data=Davis, na.action=na.omit)
linear.hypothesis(mod, diag(2), c(0,1))
## F-Test 
## SS = 245.9738     SSE = 12828.03     F = 1.735312  Df = 2 and 181     p = 0.179266 
.KW htest
.KW models
.KW regression
.WR
