.\" -*- nroff -*- generated from .Rd format
.BG
.FN recode
.TL
Recode a Variable
.DN
Recodes a numeric vector, character vector, or factor 
according to simple recode specifications.
.IP
Recode specifications appear in a character string, separated by
semicolons (see the examples below), of the form `input=output'.
If an input value satisfies more than one specification, 
then the first (from left to right) applies.
If no specification is satisfied, then the input value is carried
over to the result. `NA' is allowed on input and output.
.IP
Several recode specifications are supported.
.IP
A single value: For example, `0=NA'.
.IP
A vector of values: For example, `c(7,8,9)="high"'.
.IP
A range of values: For example, `7:9="c"'. The special values `low'
and `high' may appear in a range. For example, `low:10=1'.
.IP      
`else': everything that does not fit a previous specification.
For example, `else=NA'. Note that `else' matches all otherwise
unspecified values on input, including `NA'.
.IP
If all of the output values are numeric, and if `as.factor.result' is 
`FALSE', then a numeric result is returned.
.CS
recode(var, recodes, as.factor.result)
.RA
.AG var
numeric vector, character vector, or factor.
.AG recodes
character string of recode specifications:
see below.
.OA
.AG as.factor.result
return a factor; default is `TRUE' if 
`var' is a factor, `FALSE' otherwise.
.RT
a recoded vector of the same length as `var'; if `va'r is a factor,
then so is the result.

.SA
`cut', `factor'
.EX
x<-rep(1:3,3)
x
## [1] 1 2 3 1 2 3 1 2 3
recode(x, "c(1,2)='A'; else='B'")
## [1] "A" "A" "B" "A" "A" "B" "A" "A" "B"
recode(x, "1:2='A'; 3='B'")
## [1] "A" "A" "B" "A" "A" "B" "A" "A" "B"
.KW utilities
.WR
